@@ -124,7 +124,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 
 		powerhbox = lookup_widget (mainwindow, "powerhbox");
 		powerentry = lookup_widget (mainwindow, "powerentry");
-		if (GTK_WIDGET_VISIBLE (powerhbox))
+		if (gtk_widget_get_visible (powerhbox))
 		{
 			qso[POWER] = gtk_editable_get_chars (GTK_EDITABLE (powerentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (powerentry), 0, -1);
@@ -134,7 +134,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		qso[MYRST] = gtk_editable_get_chars (GTK_EDITABLE (myrstentry), 0, -1);
 
 		endhbox = lookup_widget (mainwindow, "endhbox");
-		if (GTK_WIDGET_VISIBLE (endhbox))
+		if (gtk_widget_get_visible (endhbox))
 		{
 			endentry = lookup_widget (mainwindow, "endentry");
 			qso[GMTEND] = gtk_editable_get_chars (GTK_EDITABLE (endentry), 0, -1);
@@ -142,7 +142,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		}
 
 		awardshbox = lookup_widget (mainwindow, "awardshbox");
-		if (GTK_WIDGET_VISIBLE (awardshbox))
+		if (gtk_widget_get_visible (awardshbox))
 		{
 			awardsentry = lookup_widget (mainwindow, "awardsentry");
 			qso[AWARDS] = gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1);
@@ -150,7 +150,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		}
 
 		qslhbox = lookup_widget (mainwindow, "qslhbox");
-		if (GTK_WIDGET_VISIBLE (qslhbox))
+		if (gtk_widget_get_visible (qslhbox))
 		{
 			incheckbutton = lookup_widget (mainwindow, "incheckbutton");
 			outcheckbutton = lookup_widget (mainwindow, "outcheckbutton");
@@ -167,7 +167,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		}
 
 		namehbox = lookup_widget (mainwindow, "namehbox");
-		if (GTK_WIDGET_VISIBLE (namehbox))
+		if (gtk_widget_get_visible (namehbox))
 		{
 			nameentry = lookup_widget (mainwindow, "nameentry");
 			qso[NAME] =	gtk_editable_get_chars (GTK_EDITABLE (nameentry), 0, -1);
@@ -175,7 +175,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		}
 
 		qthhbox = lookup_widget (mainwindow, "qthhbox");
-		if (GTK_WIDGET_VISIBLE (qthhbox))
+		if (gtk_widget_get_visible (qthhbox))
 		{
 			qthentry = lookup_widget (mainwindow, "qthentry");
 			qso[QTH] = gtk_editable_get_chars (GTK_EDITABLE (qthentry), 0, -1);
@@ -183,7 +183,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		}
 
 		locatorhbox = lookup_widget (mainwindow, "locatorhbox");
-		if (GTK_WIDGET_VISIBLE (locatorhbox))
+		if (gtk_widget_get_visible (locatorhbox))
 		{
 			locatorentry = lookup_widget (mainwindow, "locatorentry");
 			qso[LOCATOR] = gtk_editable_get_chars (GTK_EDITABLE (locatorentry), 0, -1);
@@ -191,7 +191,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		}
 
 		unknown1hbox = lookup_widget (mainwindow, "unknown1hbox");
-		if (GTK_WIDGET_VISIBLE (unknown1hbox))
+		if (gtk_widget_get_visible (unknown1hbox))
 		{
 			unknownentry1 = lookup_widget (mainwindow, "unknownentry1");
 			qso[U1] =	gtk_editable_get_chars (GTK_EDITABLE (unknownentry1), 0, -1);
@@ -199,7 +199,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		}
 
 		unknown2hbox = lookup_widget (mainwindow, "unknown2hbox");
-		if (GTK_WIDGET_VISIBLE (unknown2hbox))
+		if (gtk_widget_get_visible (unknown2hbox))
 		{
 			unknownentry2 = lookup_widget (mainwindow, "unknownentry2");
 			qso[U2] =	gtk_editable_get_chars (GTK_EDITABLE (unknownentry2), 0, -1);
@@ -207,7 +207,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		}
 
 		remarksvbox = lookup_widget (mainwindow, "remarksvbox");
-		if (GTK_WIDGET_VISIBLE (remarksvbox))
+		if (gtk_widget_get_visible (remarksvbox))
 		{
 			remtv = lookup_widget (mainwindow, "remtv");
 			b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
@@ -218,21 +218,21 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		}
 
 		/* calculate distance and azimuth */
-		if ((preferences.distqrb == 1) && GTK_WIDGET_VISIBLE (locatorhbox))
+		if ((preferences.distqrb == 1) && gtk_widget_get_visible (locatorhbox))
 		{
 			if (strlen(qso[LOCATOR]) >= 2)
 			{
 				result = locatordistance (preferences.locator, qso[LOCATOR], &kms, &l);
 				if (result == 0)
 				{
-					if (GTK_WIDGET_VISIBLE (unknown1hbox))
+					if (gtk_widget_get_visible (unknown1hbox))
 					{
 						if (preferences.units == 1)
 							qso[U1] = g_strdup_printf ("%d km", kms);
 						else
 							qso[U1] = g_strdup_printf ("%d m", (gint) (kms/1.609));
 					}
-					if (GTK_WIDGET_VISIBLE (unknown2hbox))
+					if (gtk_widget_get_visible (unknown2hbox))
 					{
 						qso[U2] = g_strdup_printf ("%d deg", l);
 					}
@@ -269,7 +269,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW(logw->treeview)), &model, &selected))
 			gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (GTK_TREE_VIEW (logw->treeview)));
 
-		if (GTK_WIDGET_VISIBLE(scorewindow))
+		if (gtk_widget_get_visible(scorewindow))
 		{
 			/* update worked/confirmed array */
 			gchar *result = valid_awards_entry (qso[AWARDS], &st, &zone, &cont, &iota);
@@ -515,7 +515,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			gmtbutton = lookup_widget (mainwindow, "gmtbutton");
 			gtk_widget_grab_focus (gmtbutton);
 
-			if (GTK_WIDGET_VISIBLE(scorewindow))
+			if (gtk_widget_get_visible(scorewindow))
 			{
 				/* update worked/confirmed array */
 				gchar *result = valid_awards_entry (awards, &st, &zone, &cont, &iota);
@@ -726,7 +726,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			}
 
 			awardshbox = lookup_widget (mainwindow, "awardshbox");
-			if (GTK_WIDGET_VISIBLE (awardshbox))
+			if (gtk_widget_get_visible (awardshbox))
 			{
 				gtk_tree_model_get (model, &selected, AWARDS, &logawards, -1);
 				awardsentry = lookup_widget (mainwindow, "awardsentry");
@@ -737,7 +737,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				logawards = g_strdup ("");
 
 			powerhbox = lookup_widget (mainwindow, "powerhbox");
-			if (GTK_WIDGET_VISIBLE (powerhbox))
+			if (gtk_widget_get_visible (powerhbox))
 			{
 				powerentry = lookup_widget (mainwindow, "powerentry");
 				qso[POWER] = gtk_editable_get_chars (GTK_EDITABLE (powerentry), 0, -1);
@@ -748,7 +748,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			qso[MYRST] = gtk_editable_get_chars (GTK_EDITABLE (myrstentry), 0, -1);
 
 			endhbox = lookup_widget (mainwindow, "endhbox");
-			if (GTK_WIDGET_VISIBLE (endhbox))
+			if (gtk_widget_get_visible (endhbox))
 			{
 				gtk_tree_model_get (model, &selected, GMTEND, &logendtime, -1);
 				endentry = lookup_widget (mainwindow, "endentry");
@@ -759,7 +759,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			}
 
 			qslhbox = lookup_widget (mainwindow, "qslhbox");
-			if (GTK_WIDGET_VISIBLE (qslhbox))
+			if (gtk_widget_get_visible (qslhbox))
 			{
 				gtk_tree_model_get (model, &selected, QSLIN, &logqslin, -1);
 				incheckbutton = lookup_widget (mainwindow, "incheckbutton");
@@ -779,7 +779,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				logqslin = g_strdup ("");
 
 			namehbox = lookup_widget (mainwindow, "namehbox");
-			if (GTK_WIDGET_VISIBLE (namehbox))
+			if (gtk_widget_get_visible (namehbox))
 			{
 				nameentry = lookup_widget (mainwindow, "nameentry");
 				qso[NAME] = gtk_editable_get_chars (GTK_EDITABLE (nameentry), 0, -1);
@@ -787,7 +787,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			}
 
 			qthhbox = lookup_widget (mainwindow, "qthhbox");
-			if (GTK_WIDGET_VISIBLE (qthhbox))
+			if (gtk_widget_get_visible (qthhbox))
 			{
 				qthentry = lookup_widget (mainwindow, "qthentry");
 				qso[QTH] = gtk_editable_get_chars (GTK_EDITABLE (qthentry), 0, -1);
@@ -795,7 +795,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			}
 
 			locatorhbox = lookup_widget (mainwindow, "locatorhbox");
-			if (GTK_WIDGET_VISIBLE (locatorhbox))
+			if (gtk_widget_get_visible (locatorhbox))
 			{
 				gtk_tree_model_get (model, &selected, LOCATOR, &loglocator, -1);
 				locatorentry = lookup_widget (mainwindow, "locatorentry");
@@ -804,7 +804,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			}
 
 			unknown1hbox = lookup_widget (mainwindow, "unknown1hbox");
-			if (GTK_WIDGET_VISIBLE (unknown1hbox))
+			if (gtk_widget_get_visible (unknown1hbox))
 			{
 				unknownentry1 = lookup_widget (mainwindow, "unknownentry1");
 				qso[U1] = gtk_editable_get_chars (GTK_EDITABLE (unknownentry1), 0, -1);
@@ -812,7 +812,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			}
 
 			unknown2hbox = lookup_widget (mainwindow, "unknown2hbox");
-			if (GTK_WIDGET_VISIBLE (unknown2hbox))
+			if (gtk_widget_get_visible (unknown2hbox))
 			{
 				unknownentry2 = lookup_widget (mainwindow, "unknownentry2");
 				qso[U2] = gtk_editable_get_chars (GTK_EDITABLE (unknownentry2), 0, -1);
@@ -820,7 +820,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			}
 
 			remarksvbox = lookup_widget (mainwindow, "remarksvbox");
-			if (GTK_WIDGET_VISIBLE (remarksvbox))
+			if (gtk_widget_get_visible (remarksvbox))
 			{
 				remtv = lookup_widget (mainwindow, "remtv");
 				b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
@@ -831,21 +831,21 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			}
 
 			/* calculate distance and azimuth */
-			if ((preferences.distqrb == 1) && GTK_WIDGET_VISIBLE (locatorhbox))
+			if ((preferences.distqrb == 1) && gtk_widget_get_visible (locatorhbox))
 			{
 				if (strlen(qso[LOCATOR]) >= 2)
 				{
 					result = locatordistance (preferences.locator, qso[LOCATOR], &kms, &l);
 					if (result == 0)
 					{
-						if (GTK_WIDGET_VISIBLE (unknown1hbox))
+						if (gtk_widget_get_visible (unknown1hbox))
 						{
 							if (preferences.units == 1)
 								qso[U1] = g_strdup_printf ("%d km", kms);
 							else
 								qso[U1] = g_strdup_printf ("%d m", (gint) (kms/1.609));
 						}
-						if (GTK_WIDGET_VISIBLE (unknown2hbox))
+						if (gtk_widget_get_visible (unknown2hbox))
 						{
 							qso[U2] = g_strdup_printf ("%d deg", l);
 						}
@@ -879,7 +879,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			temp = g_strdup_printf ("<b>%s</b>", _("New QSO"));
 			gtk_label_set_markup (GTK_LABEL (framelabel), temp);
 
-			if (GTK_WIDGET_VISIBLE(scorewindow))
+			if (gtk_widget_get_visible(scorewindow))
 			{ /* first we delete, then we add */
 				gchar *result = valid_awards_entry (logawards, &st, &zone, &cont, &iota);
 				if (result)
