@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2012 - 2015 Andy Stewart <andystewart@comcast.net>
+   Copyright (C) 2012 - 2016 Andy Stewart <kb1oiq@arrl.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -55,10 +55,10 @@ handle_email (GtkAboutDialog *about, const char *link, gpointer data)
 void
 on_menu_about_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	const gchar *authors[] = { "Andy Stewart KB1OIQ <andystewart@comcast.net>",
+	const gchar *authors[] = { "Andy Stewart KB1OIQ <kb1oiq@arrl.net>",
 		"Joop Stakenborg PG4I <pg4i@amsat.org>",
 		"Stephane Fillod F8CFE <f8cfe@free.fr>", NULL };
-	const gchar *documenters[] = { "Andy Stewart KB1OIQ <andystewart@comcast.net>",
+	const gchar *documenters[] = { "Andy Stewart KB1OIQ <kb1oiq@arrl.net>",
 				       "Joop Stakenborg PG4I <pg4i@amsat.org>",
 				       "Chris Story K6RWJ <ke6rwj@gmail.com>", 
 				       NULL };
@@ -82,7 +82,7 @@ on_menu_about_activate (GtkMenuItem * menuitem, gpointer user_data)
 		"authors", authors,
 		"documenters", documenters,
 		"comments", str,
-		"copyright", "Copyright (C) 2012 - 2015 Andy Stewart <andystewart@comcast.net>\n 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>",
+		"copyright", "Copyright (C) 2012 - 2016 Andy Stewart <kb1oiq@arrl.net>\n 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>",
 		"license",
 "Xlog is free software: you can redistribute it and/or modify "
 "it under the terms of the GNU General Public License as published by "
