@@ -49,7 +49,7 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gint response;
 
 	defaultsdialog = gtk_dialog_new_with_buttons (_("xlog - defaults"),
-		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
 		GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 
