@@ -47,6 +47,9 @@ on_fontbutton_clicked (GtkButton * button, gpointer user_data)
 
 	fontselectiondialog = gtk_font_selection_dialog_new
 		(_("xlog - select Font"));
+	gtk_window_set_modal (GTK_WINDOW(fontselectiondialog), TRUE);
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(fontselectiondialog), TRUE);
+
 	fontselectiondialog_icon_pixbuf = create_pixbuf ("xlog.png");
 	if (fontselectiondialog_icon_pixbuf)
 	{
