@@ -260,9 +260,9 @@ draw_page (GtkPrintOperation *operation, GtkPrintContext *context,
 
 		/* calculate first and last QSO for this page,
 		 * NB: page_nr starts at zero */
-		first = logwindow->qsos - (page_nr * data->lines_per_page) - 1;
+		first = logwindow->qsos - (page_nr * data->lines_per_page) -1;
 		last = first - data->lines_per_page;
-		if (last < 0) last = 0;
+		if (last < 0) last = -1;
 
 		/* print the header and calculate column width for next 50 QSO's */
 		if (boolnr) {
