@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2012 Andy Stewart <andystewart@comcast.net>
+   Copyright (C) 2012 - 2016 Andy Stewart <kb1oiq@arrl.net>
    Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -209,6 +209,16 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		hamlibresult;
 	gint hamlibwidgets = 0;
 
+	GDir *dev_serial_dir = NULL;
+	const gchar *serial_file_dir = "/dev/serial/by-id";
+	const gchar *serial_file_name = NULL;
+	const gchar *absolute_serial_file_name = NULL;
+
+	GDir *dev_dir = NULL;
+	const gchar *dev_file_dir = "/dev";
+	const gchar *dev_file_name = NULL;
+	const gchar *absolute_dev_file_name = NULL;
+
 	/**************************/
 	/* creation of the dialog */
 	/**************************/
@@ -449,18 +459,38 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (devicehbox), devicelabel, TRUE, TRUE, 0);
 	devicecombo = gtk_combo_box_entry_new_text ();
 	gtk_box_pack_start (GTK_BOX (devicehbox), devicecombo, TRUE, TRUE, 0);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "localhost");
 #ifdef G_OS_WIN32
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "com1");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "com2");
 #else
+	dev_serial_dir = g_dir_open(serial_file_dir, 0, NULL);
+	if (dev_serial_dir != NULL) {
+	  while ((serial_file_name = g_dir_read_name(dev_serial_dir)) != NULL) {
+	    absolute_serial_file_name = g_strdup_printf ("%s/%s", serial_file_dir, serial_file_name);
+	    gtk_combo_box_append_text  (GTK_COMBO_BOX (devicecombo), absolute_serial_file_name);
+	  }
+	  g_dir_close(dev_serial_dir);
+	}
+
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS0");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS1");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS2");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS3");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyUSB0");
+
+	dev_dir = g_dir_open(dev_file_dir, 0, NULL);
+	if (dev_dir != NULL) {
+	  while ((dev_file_name = g_dir_read_name(dev_dir)) != NULL) {
+	    if (! g_ascii_strncasecmp(dev_file_name, "ttyUSB", 6)) {
+	      absolute_dev_file_name = g_strdup_printf ("%s/%s", dev_file_dir, dev_file_name);
+	      gtk_combo_box_append_text  (GTK_COMBO_BOX (devicecombo), absolute_dev_file_name);
+	    }
+	  }
+	  g_dir_close(dev_dir);
+	}
+
 #endif
-	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "localhost");
-	gtk_entry_set_max_length (GTK_ENTRY (GTK_BIN(devicecombo)->child), 30);
+	gtk_entry_set_max_length (GTK_ENTRY (GTK_BIN(devicecombo)->child), 100);
 	gtk_entry_set_activates_default
 	  (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (devicecombo))), TRUE);
 
