@@ -40,7 +40,7 @@ create_savedialog (void)
 	gint response;
 
 	savedialog = gtk_dialog_new_with_buttons (_("xlog - saving"),
-		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 	vbox = gtk_vbox_new (TRUE, 0);
@@ -66,3 +66,36 @@ create_savedialog (void)
 	gtk_widget_destroy (savedialog);
 }
 
+void
+create_exitdialog (void)
+{
+	GtkWidget *exitdialog, *vbox, *image, *label;
+	gint response;
+
+	exitdialog = gtk_dialog_new_with_buttons (_("xlog - exiting"),
+		GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+	vbox = gtk_vbox_new (TRUE, 0);
+	gtk_container_add
+		(GTK_CONTAINER (GTK_DIALOG (exitdialog)->vbox), vbox);
+	image = gtk_image_new_from_stock
+		("gtk-dialog-question", GTK_ICON_SIZE_DIALOG);
+	gtk_box_pack_start (GTK_BOX (vbox), image, FALSE, FALSE, 0);
+	label = gtk_label_new
+(_("Are you sure you want to exit xlog?"));
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_misc_set_padding (GTK_MISC (label), 20, 20);
+	gtk_dialog_set_default_response (GTK_DIALOG (exitdialog),
+					 GTK_RESPONSE_OK);
+	gtk_widget_show_all (exitdialog);
+	response = gtk_dialog_run (GTK_DIALOG(exitdialog));
+	if (response == GTK_RESPONSE_OK)
+	{
+		save_windowsize_and_cleanup ();
+		gtk_main_quit ();
+	}
+	gtk_widget_destroy (exitdialog);
+}
+
