@@ -2,6 +2,7 @@
 
    xlog - GTK+ logging program for amateur radio operators
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2016 Andy Stewart <kb1oiq@arrl.net>
 
    This file is part of xlog.
 
@@ -202,6 +203,14 @@ rig_get_list (void)
 {
 	gint status;
 
+	// Bringing up the "Select a Radio" GUI would work the first time,
+	// but would crash if done twice in succession.  In the file
+	// callbacks_preferencesdialog.c, g_list_free() was being called on 
+	// this handle, which seems correct, but the list was never being
+	// re-initialized.  This line appears to fix the problem.
+	// AndyS 31-july-2016
+	rigs = NULL;  // start with an empty list
+
 	rig_load_all_backends ();
 	status = rig_list_foreach (riglist_make_list, NULL);
 	return rigs;
