@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -27,9 +27,10 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <stdio.h>
 #include <glib.h>
 #include <time.h>
+#include <ctype.h>
+#include <glib/gstdio.h>
 
 #include "logfile.h"
 
@@ -80,7 +81,7 @@ editest_open (LOGDB * handle)
 {
   FILE *fp;
 
-  fp = fopen (handle->path, "r");
+  fp = g_fopen (handle->path, "r");
   if (!fp)
     return -1;
   handle->priv = (gpointer) fp;
@@ -100,7 +101,7 @@ editest_create (LOGDB * handle)
 {
   FILE *fp;
 
-  fp = fopen (handle->path, "w");
+  fp = g_fopen (handle->path, "w");
   if (!fp)
     return -1;
   handle->priv = (gpointer) fp;
@@ -144,7 +145,7 @@ editest_qso_append (LOGDB * handle, const qso_t * q)
 //const gint editest_fields[] = { DATE, GMT, CALL, RST, MYRST, LOCATOR, BAND };
 
   if (strlen (q[DATE]) == 11 && q[DATE][2] == ' ' && q[DATE][6] == ' ')
-    sprintf (date, "%c%c-%02d-%s", q[DATE][0], q[DATE][1],
+    sprintf (date, "%c%c-%02u-%s", q[DATE][0], q[DATE][1],
 	     scan_month (q[DATE] + 3), q[DATE] + 9);
 
   if (q[NR] && (!q[LOCATOR] || strlen (q[LOCATOR]) == 0))
@@ -170,6 +171,27 @@ editest_qso_append (LOGDB * handle, const qso_t * q)
   return 0;
 }
 
+static const gchar * band2freq(const gchar *field)
+{
+
+	gint band;
+	const gchar*fr;
+
+	band = atoi(field);
+
+	switch (band)
+	{
+		case 160: fr = "1.8"; break;
+		case 80: fr = "3.5"; break;
+		case 40: fr = "7"; break;
+		case 20: fr = "14"; break;
+		case 15: fr = "21"; break;
+		case 10: fr = "28"; break;
+		default: fr = field;
+	}
+	return fr;
+}
+
 #define MAXROWLEN 120
 
 gint
@@ -215,9 +237,11 @@ editest_qso_foreach (LOGDB * handle,
 		  struct tm timestruct;
 		  gchar sdate[16];
 
-		  sscanf (field, "%2i-%2i-%2i",
+		  memset(&timestruct, 0, sizeof(timestruct));
+		  sscanf (field, "%u-%u-%u",
 			  &timestruct.tm_mday,
-			  &timestruct.tm_mon, &timestruct.tm_year);
+			  &timestruct.tm_mon,
+			  &timestruct.tm_year);
 		  if (timestruct.tm_year < 70)
 		    timestruct.tm_year += 100;
 		  timestruct.tm_mon--;
@@ -239,6 +263,13 @@ editest_qso_foreach (LOGDB * handle,
 		  qfield = g_strdup (gmt);
 		  break;
 		}
+              case BAND:
+		qfield = g_strdup (band2freq(field));
+		break;
+              case LOCATOR:
+		/* HF logs don't have locator, but useless NR */
+		qfield = g_strdup ( isalpha(field[0]) ? field : "");
+		break;
 	      default:
 		qfield = g_strdup (field);
 	      }
